@@ -1,3 +1,5 @@
+import django
+
 try:
     from django.contrib.auth.decorators import login_not_required
 except ImportError:
@@ -8,3 +10,11 @@ except ImportError:
         """
         view_func.login_required = False
         return view_func
+
+
+if django.VERSION >= (6, 0):
+    from django.middleware.csp import get_nonce
+else:
+    # For Django < 6.0, there is no native CSP support, hence no CSP nonces.
+    def get_nonce(request):
+        return None
