@@ -1,8 +1,9 @@
 from __future__ import annotations
 
-from typing import Any, NamedTuple, Optional
+from typing import Any, NamedTuple, Protocol
 
 from django import template as dj_template
+from django.http import HttpRequest, HttpResponse
 
 
 class InspectStack(NamedTuple):
@@ -14,7 +15,7 @@ class InspectStack(NamedTuple):
     index: int
 
 
-TidyStackTrace = list[tuple[str, int, str, str, Optional[Any]]]
+TidyStackTrace = list[tuple[str, int, str, str, Any | None]]
 
 
 class RenderContext(dj_template.context.RenderContext):
@@ -24,3 +25,7 @@ class RenderContext(dj_template.context.RenderContext):
 class RequestContext(dj_template.RequestContext):
     template: dj_template.Template
     render_context: RenderContext
+
+
+class GetResponse(Protocol):
+    def __call__(self, request: HttpRequest) -> HttpResponse: ...
