@@ -3,6 +3,7 @@ from django.template.loader import render_to_string
 from django.utils.functional import classproperty
 
 from debug_toolbar import settings as dt_settings
+from debug_toolbar._stubs import GetResponse
 from debug_toolbar.utils import get_name_from_obj
 
 
@@ -13,7 +14,7 @@ class Panel:
 
     is_async = False
 
-    def __init__(self, toolbar, get_response):
+    def __init__(self, toolbar, get_response: GetResponse):
         self.toolbar = toolbar
         self.get_response = get_response
         self.from_store = False
@@ -21,7 +22,7 @@ class Panel:
     # Private panel properties
 
     @classproperty
-    def panel_id(cls):
+    def panel_id(cls) -> str:
         return cls.__name__
 
     @property
