@@ -1,23 +1,28 @@
+from __future__ import annotations
+
 import inspect
 import linecache
 import os.path
 import sys
 import warnings
+from collections.abc import Sequence
 from pprint import PrettyPrinter, pformat
-from typing import Any, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any
 
 from asgiref.local import Local
 from django.http import QueryDict
 from django.template import Node
 from django.utils.html import format_html
 from django.utils.safestring import SafeString, mark_safe
+from django.views.debug import get_default_exception_reporter_filter
 
-from debug_toolbar import _stubs as stubs, settings as dt_settings
+from debug_toolbar import _compat as compat, _stubs as stubs, settings as dt_settings
 
 _local_data = Local()
+safe_filter = get_default_exception_reporter_filter()
 
 
-def _is_excluded_frame(frame: Any, excluded_modules: Optional[Sequence[str]]) -> bool:
+def _is_excluded_frame(frame: Any, excluded_modules: Sequence[str] | None) -> bool:
     if not excluded_modules:
         return False
     frame_module = frame.f_globals.get("__name__")
@@ -39,7 +44,7 @@ def _stack_trace_deprecation_warning() -> None:
     )
 
 
-def tidy_stacktrace(stack: List[stubs.InspectStack]) -> stubs.TidyStackTrace:
+def tidy_stacktrace(stack: list[stubs.InspectStack]) -> stubs.TidyStackTrace:
     """
     Clean up stacktrace and remove all entries that are excluded by the
     HIDE_IN_STACKTRACES setting.
@@ -99,7 +104,7 @@ def render_stacktrace(trace: stubs.TidyStackTrace) -> SafeString:
     return mark_safe(html)
 
 
-def get_template_info() -> Optional[Dict[str, Any]]:
+def get_template_info() -> dict[str, Any] | None:
     template_info = None
     cur_frame = sys._getframe().f_back
     try:
@@ -129,7 +134,7 @@ def get_template_info() -> Optional[Dict[str, Any]]:
 
 def get_template_context(
     node: Node, context: stubs.RequestContext, context_lines: int = 3
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     line, source_lines, name = get_template_source_from_exception_info(node, context)
     debug_context = []
     start = max(1, line - context_lines)
@@ -146,7 +151,7 @@ def get_template_context(
 
 def get_template_source_from_exception_info(
     node: Node, context: stubs.RequestContext
-) -> Tuple[int, List[Tuple[int, str]], str]:
+) -> tuple[int, list[tuple[int, str]], str]:
     if context.template.origin == node.origin:
         exception_info = context.template.get_exception_info(
             Exception("DDT"), node.token
@@ -212,23 +217,53 @@ def getframeinfo(frame: Any, context: int = 1) -> inspect.Traceback:
     return inspect.Traceback(filename, lineno, frame.f_code.co_name, lines, index)
 
 
-def get_sorted_request_variable(
-    variable: Union[Dict[str, Any], QueryDict],
-) -> Dict[str, Union[List[Tuple[str, Any]], Any]]:
+def sanitize_and_sort_request_vars(
+    variable: dict[str, Any] | QueryDict,
+) -> dict[str, list[tuple[str, Any]] | Any]:
     """
     Get a data structure for showing a sorted list of variables from the
-    request data.
+    request data with sensitive values redacted.
     """
-    try:
-        if isinstance(variable, dict):
-            return {"list": [(k, variable.get(k)) for k in sorted(variable)]}
-        else:
-            return {"list": [(k, variable.getlist(k)) for k in sorted(variable)]}
-    except TypeError:
+    if not isinstance(variable, (dict, QueryDict)):
         return {"raw": variable}
 
+    # Get sorted keys if possible, otherwise just list them
+    keys = _get_sorted_keys(variable)
 
-def get_stack(context=1) -> List[stubs.InspectStack]:
+    # Process the variable based on its type
+    if isinstance(variable, QueryDict):
+        result = _process_query_dict(variable, keys)
+    else:
+        result = _process_dict(variable, keys)
+
+    return {"list": result}
+
+
+def _get_sorted_keys(variable):
+    """Helper function to get sorted keys if possible."""
+    try:
+        return sorted(variable)
+    except TypeError:
+        return list(variable)
+
+
+def _process_query_dict(query_dict, keys):
+    """Process a QueryDict into a list of (key, sanitized_value) tuples."""
+    result = []
+    for k in keys:
+        values = query_dict.getlist(k)
+        # Return single value if there's only one, otherwise keep as list
+        value = values[0] if len(values) == 1 else values
+        result.append((k, safe_filter.cleanse_setting(k, value)))
+    return result
+
+
+def _process_dict(dictionary, keys):
+    """Process a dictionary into a list of (key, sanitized_value) tuples."""
+    return [(k, safe_filter.cleanse_setting(k, dictionary.get(k))) for k in keys]
+
+
+def get_stack(context=1) -> list[stubs.InspectStack]:
     """
     Get a list of records for a frame and all higher (calling) frames.
 
@@ -286,7 +321,7 @@ class _StackTraceRecorder:
     def get_stack_trace(
         self,
         *,
-        excluded_modules: Optional[Sequence[str]] = None,
+        excluded_modules: Sequence[str] | None = None,
         include_locals: bool = False,
         skip: int = 0,
     ):
@@ -366,3 +401,17 @@ def is_processable_html_response(response):
         and content_encoding == ""
         and content_type in _HTML_TYPES
     )
+
+
+def get_csp_nonce(request) -> str | None:
+    """
+    Retrieve the Content Security Policy nonce from a request if there is one.
+
+    This supports both the django-csp and the built-in Django implementations.
+    """
+    # django-csp uses request.csp_nonce
+    csp_nonce = getattr(request, "csp_nonce", None)
+    if csp_nonce is not None:
+        return csp_nonce
+    # Django's built-in CSP support uses get_nonce(request)
+    return compat.get_nonce(request)
